@@ -54,6 +54,7 @@ class Route(object):
         # Don't bother forming stuff we don't need if its a static route
         self.static = kargs.get('_static', False)
         self.filter = kargs.pop('_filter', None)
+        self.absolute = kargs.pop('_absolute', False)
         
         # Pull out route conditions
         self.conditions = kargs.pop('conditions', None)
@@ -377,7 +378,7 @@ class Route(object):
         
         return result
     
-    def generate(self, _ignore_req_list=False, **kargs):
+    def generate(self, _ignore_req_list=False, _append_slash=False, **kargs):
         """Generate a URL from ourself given a set of keyword arguments
         
         Toss an exception if this
@@ -462,9 +463,13 @@ class Route(object):
             url = '/' + url
         extras = frozenset(kargs.keys()) - self.maxkeys
         if extras:
+            if _append_slash and not url.endswith('/'):
+                url += '/'
             url += '?'
             url += urllib.urlencode([(key, kargs[key]) for key in kargs if key in extras and \
                                      (key != 'action' or key != 'controller')])
+        elif _append_slash and not url.endswith('/'):
+            url += '/'
         return url
     
 
@@ -709,6 +714,9 @@ class Mapper(object):
         if not self._created_gens:
             self._create_gens()
         
+        if self.append_slash:
+            kargs['_append_slash'] = True
+        
         kargs['controller'] = controller
         kargs['action'] = action
         
@@ -783,7 +791,8 @@ class Mapper(object):
             if path:
                 if self.prefix:
                     path = self.prefix + path
-                if self.environ and self.environ.get('SCRIPT_NAME', '') != '':
+                if self.environ and self.environ.get('SCRIPT_NAME', '') != '' \
+                    and not route.absolute:
                     path = self.environ['SCRIPT_NAME'] + path
                 if self.urlcache is not None:
                     self.urlcache[str(kargs)] = path
@@ -792,14 +801,20 @@ class Mapper(object):
                 continue
         return None
     
-    def resource(self, controller_name, **kwargs):
+    def resource(self, member_name, collection_name, **kwargs):
         """Generate routes for a controller resource
         
-        The controller should be the name of the controller for which a set
-        of resource-based Routes should be generated. The concept of a web
-        resource maps somewhat directly to 'CRUD' operations. The overlying
-        things to keep in mind is that mapping a resource is about handling
-        creating, viewing, and editing that resource.
+        The member_name name should be the appropriate singular version of the
+        resource given your locale and used with members of the collection.
+        The collection_name name will be used to refer to the resource 
+        collection methods and should be a plural version of the member_name
+        argument. By default, the member_name name will also be assumed to map
+        to a controller you create.
+        
+        The concept of a web resource maps somewhat directly to 'CRUD' 
+        operations. The overlying things to keep in mind is that mapping a
+        resource is about handling creating, viewing, and editing that
+        resource.
         
         All keyword arguments are optional.
         
@@ -857,7 +872,6 @@ class Mapper(object):
                 # has named route "category_message"
         
         """
-        controller = controller_name
         collection = kwargs.pop('collection', {})
         member = kwargs.pop('member', {})
         new = kwargs.pop('new', {})
@@ -884,7 +898,7 @@ class Mapper(object):
         member_methods.setdefault('DELETE', []).insert(0, 'delete')
         
         # If there's a path prefix option, use it with the controller
-        controller = strip_slashes(controller)
+        controller = strip_slashes(collection_name)
         path_prefix = strip_slashes(path_prefix)
         if path_prefix:
             path = path_prefix + '/' + controller
@@ -910,7 +924,7 @@ class Mapper(object):
             route_options = requirements_for(method)
             for action in lst:
                 route_options['action'] = action
-                route_name = "%s%s_%s" % (name_prefix, action, controller)
+                route_name = "%s%s_%s" % (name_prefix, action, collection_name)
                 self.connect(route_name, "%s;%s" % (collection_path, action), **route_options)
                 self.connect("formatted_" + route_name, "%s.:(format);%s" % (collection_path, action))
             if primary:
@@ -920,9 +934,9 @@ class Mapper(object):
         
         # Specifically add in the built-in 'index' collection method and its formatted
         # version
-        self.connect(name_prefix + controller, collection_path, action='index', 
+        self.connect(name_prefix + collection_name, collection_path, action='index', 
             conditions={'method':['GET']}, **options)
-        self.connect("formatted_" + name_prefix + controller, 
+        self.connect("formatted_" + name_prefix + collection_name, 
             collection_path + ".:(format)", action='index', 
             conditions={'method':['GET']}, **options)
         
@@ -931,7 +945,7 @@ class Mapper(object):
             route_options = requirements_for(method)
             for action in lst:
                 path = (action == 'new' and new_path) or "%s;%s" % (new_path, action)
-                name = "new_" + controller
+                name = "new_" + member_name
                 if action != 'new': name = action + "_" + name
                 route_options['action'] = action
                 self.connect(name_prefix + name, path, **route_options)
@@ -949,9 +963,9 @@ class Mapper(object):
                 primary = None
             for action in lst:
                 route_options['action'] = action
-                self.connect("%s%s_%s" % (name_prefix, action, controller),
+                self.connect("%s%s_%s" % (name_prefix, action, member_name),
                     "%s;%s" % (member_path, action), **route_options)
-                self.connect("formatted_%s%s_%s" % (name_prefix, action, controller),
+                self.connect("formatted_%s%s_%s" % (name_prefix, action, member_name),
                     "%s.:(format);%s" % (member_path, action), **route_options)
             if primary:
                 route_options['action'] = primary
@@ -961,7 +975,7 @@ class Mapper(object):
         route_options = requirements_for('GET')
         route_options['action'] = 'show'
         route_options['requirements'] = {'id':'\w+'}
-        self.connect(name_prefix + controller, member_path, **route_options)
-        self.connect("formatted_" + name_prefix + controller, member_path + ".:(format)",
+        self.connect(name_prefix + member_name, member_path, **route_options)
+        self.connect("formatted_" + name_prefix + member_name, member_path + ".:(format)",
             **route_options)
     
