@@ -45,7 +45,8 @@ def _screenargs(kargs):
 def _subdomain_check(config, kargs):
     if config.mapper.sub_domains:
         subdomain = kargs.pop('sub_domain', None)
-        hostmatch = config.environ['HTTP_HOST'].split(':')
+        fullhost = config.environ.get('HTTP_HOST') or config.environ.get('SERVER_NAME')
+        hostmatch = fullhost.split(':')
         host = hostmatch[0]
         port = ''
         if len(hostmatch) > 1:
@@ -154,8 +155,6 @@ def url_for(*args, **kargs):
         host = newargs.pop('_host', None) or host
         protocol = newargs.pop('_protocol', None) or protocol
         url = config.mapper.generate(**newargs)
-        if config.mapper.append_slash and not url.endswith('/'):
-            url += '/'
     if anchor: url += '#' + _url_quote(anchor)
     if host or protocol or qualified:
         if not host and not qualified:
@@ -181,7 +180,7 @@ def redirect_to(*args, **kargs):
     """
     target = url_for(*args, **kargs)
     config = request_config()
-    config.redirect(target)
+    return config.redirect(target)
 
 def controller_scan(directory=None):
     """
