@@ -729,7 +729,41 @@ class TestRecognition(unittest.TestCase):
         con.environ = env
         self.assertEqual({'action': 'index', 'controller': 'content', 'sub_domain': None, 'id': None},
             con.mapper_dict)
+    
+    def test_resource(self):
+        m = Mapper()
+        m.resource('person', 'people')
+        m.create_regs(['people'])
+        
+        con = request_config()
+        con.mapper = m
+        def test_path(path, method):
+            env = dict(HTTP_HOST='example.com', PATH_INFO=path, REQUEST_METHOD=method)
+            con.mapper_dict = {}
+            con.environ = env
+        
+        test_path('/people', 'GET')
+        assert {'controller':'people', 'action':'index'} == con.mapper_dict
+        test_path('/people', 'get')
+        assert {'controller':'people', 'action':'index'} == con.mapper_dict
+        
+        test_path('/people', 'POST')
+        assert {'controller':'people', 'action':'create'} == con.mapper_dict
+        test_path('/people', 'post')
+        assert {'controller':'people', 'action':'create'} == con.mapper_dict
+        
+        test_path('/people/2', 'GET')
+        assert {'controller':'people', 'action':'show', 'id':'2'} == con.mapper_dict
+        test_path('/people/2;edit', 'GET')
+        assert {'controller':'people', 'action':'edit', 'id':'2'} == con.mapper_dict
 
+        test_path('/people/2', 'DELETE')
+        assert {'controller':'people', 'action':'delete', 'id':'2'} == con.mapper_dict
+        test_path('/people/2', 'delete')
+        assert {'controller':'people', 'action':'delete', 'id':'2'} == con.mapper_dict
+
+        test_path('/people/2', 'PUT')
+        assert {'controller':'people', 'action':'update', 'id':'2'} == con.mapper_dict        
 
 
 if __name__ == '__main__':
